struct SenderDropGuard(Option<Sender>);Expand description
A drop guard for the body Sender.
If the Dispatcher future is dropped (e.g. the runtime driving the
connection is shut down) while it still owns a body Sender, the guard
sends an incomplete-message error so the receiver sees an error instead
of a silent, clean end-of-stream.
Tuple Fields
0: Option<Sender>Implementations